@@ -87,6 +87,10 @@ def repo_data():
             "content": raw_file("repo_files/zuul.d/no-jobs.yaml"),
             "blame": [],
         },
+        "zuul.d/jobs-parse-error.yaml": {
+            "content": raw_file("repo_files/zuul.d/jobs-parse-error.yaml"),
+            "blame": [],
+        },
     }
 
     role_files = {
@@ -179,7 +183,7 @@ def github_response_access_token():
     expires_future = datetime.now(timezone.utc)
     expires_future += timedelta(minutes=10)
     response = {
-        "token": "v1.6a01e67ed5a45dff724d99694a325a090ab69419",
+        "token": "THIS_IS_NOT_A_TOKEN",
         "expires_at": datetime.strftime(expires_future, "%Y-%m-%dT%H:%M:%SZ"),
     }
     return response
